use clap::{Parser, Subcommand};
use std::path::PathBuf;

#[derive(Parser)]
#[command(author, version, about, long_about = None)]
pub struct Cli {
    #[command(subcommand)]
    pub command: Commands,
}

#[derive(Subcommand)]
pub enum Commands {
    /// Create a ticket
    Create {
        /// The project key in which to create the ticket
        #[arg(long)]
        project: Option<String>,

        /// Open the new ticket in a browser
        #[arg(long)]
        open: bool,

        /// A markdown file
        #[arg(value_name = "MARKDOWN_FILE")]
        markdown_file: Option<PathBuf>,
    },
    /// Find tickets currently assigned to you
    List {
        /// Print json rather than pretty print
        #[arg(long)]
        json: bool,
    },
    /// Setup the configuration
    Init {
        /// Jira instance URL
        #[arg(long)]
        url: String,
        /// User email
        #[arg(long)]
        email: String,
        /// User Token
        #[arg(long)]
        token: String,
    },
}
